# coding: utf-8

"""
    AI Hub API

    The AI Hub REST API. See https://docs.instabase.com/api-sdk/ for more details.

    The version of the OpenAPI document: 0.1
    Contact: support@instabase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class CreateBatchRequest(BaseModel):
    """
    CreateBatchRequest
    """ # noqa: E501
    name: StrictStr = Field(description="Name of the batch. Maximum length is 255 characters.")
    workspace: Optional[StrictStr] = Field(default=None, description="The name of the workspace in which to add the batch; the batch is created in the default drive of the workspace. If not specified, the default location for organization members is the default drive of your personal workspace. For community users, the default location is your personal workspace's Instabase Drive.  When making this call from a service account, you must specify a workspace.  <Info>For organization members, if the default drive changes but is still connected, you can still use the batch as input for running an app. However, you can't upload any additional files to the batch. If the default drive is disconnected, you can't use batches stored on that drive as input for any app run.</Info> ")
    __properties: ClassVar[List[str]] = ["name", "workspace"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of CreateBatchRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of CreateBatchRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "workspace": obj.get("workspace")
        })
        return _obj





# coding: utf-8

"""
    AI Hub API

    The AI Hub REST API. See https://docs.instabase.com/api-sdk/ for more details.

    The version of the OpenAPI document: 0.1
    Contact: support@instabase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictInt, StrictStr
from pydantic import Field
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class BatchInfo(BaseModel):
    """
    BatchInfo
    """ # noqa: E501
    id: StrictInt = Field(description="The batch ID.")
    name: StrictStr = Field(description="The batch name.")
    workspace: Optional[StrictStr] = Field(default=None, description="The name of the workspace in which the batch exists.")
    mount_point: Optional[StrictStr] = Field(default=None, description="The name of the connected drive in which the batch is stored.")
    repo_owner: Optional[StrictStr] = Field(default=None, description="The owner of the workspace (also known as the repo) in which the batch exists.")
    batch_owner: Optional[StrictStr] = Field(default=None, description="Username of the user that created the batch.")
    created_at_ms: Optional[StrictInt] = Field(default=None, description="When the batch was created, in Unix time.")
    updated_at_ms: Optional[StrictInt] = Field(default=None, description="When the batch was last updated, in Unix time.")
    path_suffix: Optional[StrictStr] = Field(default=None, description="Batch path suffix from the mount point.")
    __properties: ClassVar[List[str]] = ["id", "name", "workspace", "mount_point", "repo_owner", "batch_owner", "created_at_ms", "updated_at_ms", "path_suffix"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BatchInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of BatchInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "workspace": obj.get("workspace"),
            "mount_point": obj.get("mount_point"),
            "repo_owner": obj.get("repo_owner"),
            "batch_owner": obj.get("batch_owner"),
            "created_at_ms": obj.get("created_at_ms"),
            "updated_at_ms": obj.get("updated_at_ms"),
            "path_suffix": obj.get("path_suffix")
        })
        return _obj





import json
import unittest
from unittest.mock import patch
import urllib3

from aihub.api.runs_api import RunsApi


class TestRunsApi(unittest.TestCase):
  """RunsApi unit test stubs"""

  def setUp(self) -> None:
    self.api = RunsApi()

  def tearDown(self) -> None:
    pass

  @patch.object(urllib3.PoolManager, 'request')
  def test_get_run_results(self, mock_request) -> None:
    """Test case for get_run_results

        Retrieve run results
        """
    run_id = "run123"
    expected_response = {
        'has_more':
        False,
        'batch_id':
        '12937',
        'files': [{
            'original_file_name':
            'new_file.txt',
            'documents': [{
                'class_name':
                'Other',
                'fields': [{
                    'value':
                    '1234 1234 1234 1234',
                    'type':
                    'TEXT',
                    'confidence': {
                        'model': 0.9998947
                    },
                    'edit_history': [],
                    'source_coordinates': [{
                        'top_x': 393.71,
                        'top_y': 132.91,
                        'bottom_x': 465.15000244140623,
                        'bottom_y': 149.08,
                        'page_number': 0
                    }, {
                        'top_x': 474.6,
                        'top_y': 132.91,
                        'bottom_x': 546.0400024414063,
                        'bottom_y': 149.08,
                        'page_number': 0
                    }, {
                        'top_x': 555.49,
                        'top_y': 132.91,
                        'bottom_x': 626.9300024414063,
                        'bottom_y': 149.08,
                        'page_number': 0
                    }, {
                        'top_x': 636.38,
                        'top_y': 132.91,
                        'bottom_x': 707.8200024414062,
                        'bottom_y': 149.08,
                        'page_number': 0
                    }],
                    'validations':
                    None,
                    'field_name':
                    'account_number'
                }],
                'post_processed_paths': [
                    'test_user/my-repo/fs/Instabase Drive/app-runs/976bf734-6271-44c3-860d-ea75c0c93f2c/ef0d286a-3da1-4330-b13a-059257b646ea/s1_process_files/images/new_file.txt_p0.jpeg'
                ],
                'review_completed':
                False,
                'class_edit_history': [],
                'validations': {
                    'final_result_pass': None
                },
                'doc_id':
                None
            }]
        }],
        'review_completed':
        False
    }

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.get_run_results(run_id)
    self.assertFalse(response.has_more)
    # Assert results file structure
    self.assertEqual(len(response.files), 1)
    self.assertEqual(response.files[0].original_file_name, "new_file.txt")
    # Assert document structure
    self.assertEqual(len(response.files[0].documents), 1)
    self.assertEqual(len(response.files[0].documents[0].fields), 1)
    # Assert field structure
    self.assertEqual(response.files[0].documents[0].fields[0].field_name,
                     "account_number")
    self.assertEqual(response.files[0].documents[0].fields[0].value,
                     "1234 1234 1234 1234")
    self.assertEqual(response.files[0].documents[0].fields[0].type, "TEXT")
    self.assertEqual(response.files[0].documents[0].fields[0].confidence.model,
                     0.9998947)
    self.assertEqual(
        len(response.files[0].documents[0].fields[0].source_coordinates), 4)
    self.assertEqual(
        len(response.files[0].documents[0].post_processed_paths), 1)
    # Assert other document fields
    self.assertEqual(response.files[0].documents[0].class_name, "Other")
    self.assertEqual(response.files[0].documents[0].review_completed, False)
    self.assertEqual(
        response.files[0].documents[0].validations.final_result_pass, None)
    self.assertEqual(response.files[0].documents[0].doc_id, None)
    self.assertEqual(response.review_completed, False)
    self.assertEqual(response.batch_id, '12937')

  @patch.object(urllib3.PoolManager, 'request')
  def test_get_run_results_all_flags(self, mock_request) -> None:
    """Test case for get_run_results

        Retrieve run results for all options
        """
    run_id = "run123"
    expected_response = {
        "has_more":
        False,
        "batch_id":
        '1251',
        "files": [{
            "original_file_name":
            "willy.pdf",
            "documents": [{
                "class_name":
                "Wage And Tax Statement",
                "fields": [{
                    "field_name": "field_1",
                    "value": "other",
                    "type": "TEXT",
                    "confidence": {
                        "model": 0.12
                    },
                    "edit_history": [],
                    "source_coordinates": [],
                    "validations": {
                        "valid": True,
                        "alerts": []
                    }
                }, {
                    "field_name":
                    "employers_address_and_ZIP_code",
                    "value":
                    "757 Martin Hill Suite 056 East Kyle SC 74614-1778",
                    "type":
                    "TEXT",
                    "confidence": {
                        "model": 0.70431864
                    },
                    "edit_history": [{
                        "modification_timestamp":
                        "2024-07-01 16:00:00",
                        "user_id":
                        "willy",
                        "modifications": [{
                            "message": "edited to 'X'"
                        }]
                    }],
                    "source_coordinates": [{
                        "top_x": 153.0,
                        "top_y": 573.33,
                        "bottom_x": 191.69999885559082,
                        "bottom_y": 584.08,
                        "page_number": 0
                    }, {
                        "top_x": 205.0,
                        "top_y": 573.33,
                        "bottom_x": 282.39999771118164,
                        "bottom_y": 584.08,
                        "page_number": 0
                    }],
                    "validations": {
                        "valid":
                        False,
                        "alerts": [{
                            "alert_level": "failure",
                            "msg":
                            "Field [Wage And Tax Statement.employers_address_and_ZIP_code] confidence value was lower than threshold 0.95",
                            "blocked": False,
                            "type": "confidence",
                            "locations": []
                        }]
                    }
                }],
                "post_processed_paths": [
                    "instabase-sandbox-org/support-testing.aihubuat-orguser_instabase.com/fs/S3 Test Drive/app-runs/5faf5dc6-dd97-42cb-8b8e-28a63066887e/1716916997868/output/s1_process_files/images/W2_Multi_Sample_Data_input_ADP1_clean_15517-19 (1).pdf_p0.JPEG.jpeg",
                    "instabase-sandbox-org/support-testing.aihubuat-orguser_instabase.com/fs/S3 Test Drive/app-runs/5faf5dc6-dd97-42cb-8b8e-28a63066887e/1716916997868/output/s1_process_files/images/W2_Multi_Sample_Data_input_ADP1_clean_15517-19 (1).pdf_p1.JPEG.jpeg",
                    "instabase-sandbox-org/support-testing.aihubuat-orguser_instabase.com/fs/S3 Test Drive/app-runs/5faf5dc6-dd97-42cb-8b8e-28a63066887e/1716916997868/output/s1_process_files/images/W2_Multi_Sample_Data_input_ADP1_clean_15517-19 (1).pdf_p2.JPEG.jpeg"
                ],
                "review_completed":
                False,
                "class_edit_history": [],
                "validations": {
                    "final_result_pass": False
                },
                "doc_id":
                63333
            }]
        }],
        "review_completed":
        False
    }

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.get_run_results(
        run_id,
        include_confidence_scores=True,
        include_source_info=True,
        include_review_results=True,
        include_validation_results=True,
        file_offset=0)
    self.assertFalse(response.has_more)
    self.assertEqual(response.review_completed, False)
    self.assertEqual(len(response.files), 1)
    self.assertEqual(response.files[0].original_file_name, "willy.pdf")
    self.assertEqual(len(response.files[0].documents), 1)
    self.assertEqual(len(response.files[0].documents[0].fields), 2)
    self.assertEqual(
        len(response.files[0].documents[0].post_processed_paths), 3)

    # first field
    first_field = response.files[0].documents[0].fields[0]
    self.assertEqual(first_field.field_name, 'field_1')
    self.assertEqual(first_field.value, 'other')
    self.assertEqual(first_field.confidence.model, 0.12)
    self.assertEqual(first_field.validations.valid, True)
    self.assertEqual(len(first_field.source_coordinates), 0)
    self.assertEqual(len(first_field.edit_history), 0)

    # second field
    second_field = response.files[0].documents[0].fields[1]
    self.assertEqual(second_field.field_name, 'employers_address_and_ZIP_code')
    self.assertEqual(second_field.value,
                     '757 Martin Hill Suite 056 East Kyle SC 74614-1778')
    self.assertEqual(second_field.confidence.model, 0.70431864)
    self.assertEqual(second_field.validations.valid, False)
    self.assertEqual(
        second_field.validations.alerts[0].msg,
        "Field [Wage And Tax Statement.employers_address_and_ZIP_code] confidence value was lower than threshold 0.95"
    )
    self.assertEqual(len(second_field.source_coordinates), 2)
    self.assertEqual(len(second_field.edit_history), 1)
    self.assertEqual(second_field.edit_history[0].modifications[0].message,
                     "edited to 'X'")

  @patch.object(urllib3.PoolManager, 'request')
  def test_get_run_status(self, mock_request) -> None:
    """Test case for get_run_status

        Get the status of a run.
        """
    run_id = "run123"
    expected_response = {"id": run_id, "status": "COMPLETE"}

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.get_run_status(run_id)
    self.assertEqual(response.id, run_id)
    self.assertEqual(response.status, "COMPLETE")

  @patch.object(urllib3.PoolManager, 'request')
  def test_run_app(self, mock_request) -> None:
    """Test case for run_app

        Run a given app.
        """
    app_id = "app123"
    batch_id = 123
    expected_response = {"id": "run123", "status": "RUNNING"}

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.run_app({'app_id': app_id, 'batch_id': batch_id})
    self.assertEqual(response.id, "run123")
    self.assertEqual(response.status, "RUNNING")

  @patch.object(urllib3.PoolManager, 'request')
  def test_run_app_input_dir(self, mock_request) -> None:
    """Test case for run_app

        Run a given app.
        """
    app_id = "app123"
    expected_response = {"id": "run123", "status": "RUNNING"}

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.run_app({
        'app_id': app_id,
        'input_dir': 'ib/my-repo/Instabase Drive'
    })
    self.assertEqual(response.id, "run123")
    self.assertEqual(response.status, "RUNNING")

  @patch.object(urllib3.PoolManager, 'request')
  def test_run_deployment_with_batch(self, mock_request) -> None:
    """Test case for run_deployment with a batch

    Run deployment
    """
    deployment_id = "deployment123"
    batch_id = 123
    expected_response = {
        "id": "run123",
        "status": "RUNNING",
        "msg": "",
        "start_timestamp": 100,
        "finish_timestamp": 200
    }

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=202)
    mock_request.return_value = mock_response

    response = self.api.run_deployment(deployment_id, {'batch_id': batch_id})
    self.assertEqual(response.id, "run123")
    self.assertEqual(response.status, "RUNNING")
    self.assertEqual(response.msg, "")
    self.assertEqual(response.start_timestamp, 100)
    self.assertEqual(response.finish_timestamp, 200)

  @patch.object(urllib3.PoolManager, 'request')
  def test_run_deployment_with_upstream_integration(self,
                                                    mock_request) -> None:
    """Test case for run_deployment with an upstream integration

    Run deployment
    """
    deployment_id = "deployment123"
    expected_response = {
        "id": "run123",
        "status": "RUNNING",
        "msg": "",
        "start_timestamp": 100,
        "finish_timestamp": 200
    }

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=202)
    mock_request.return_value = mock_response

    response = self.api.run_deployment(
        deployment_id, {
            'manual_upstream_integration': True,
            'from_timestamp': 0,
            'to_timestamp': 1734133834
        })
    self.assertEqual(response.id, "run123")
    self.assertEqual(response.status, "RUNNING")
    self.assertEqual(response.msg, "")
    self.assertEqual(response.start_timestamp, 100)
    self.assertEqual(response.finish_timestamp, 200)

  @patch.object(urllib3.PoolManager, 'request')
  def test_list_runs(self, mock_request) -> None:
    """Test case for list_runs

        List all runs.
        """
    expected_response = {
        "runs": [{
            "id": "run123",
            "status": "RUNNING",
            "msg": "",
            "start_timestamp": 100,
            "finish_timestamp": 200
        }]
    }

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.list_runs()
    self.assertEqual(len(response.runs), 1)
    self.assertEqual(response.runs[0].id, "run123")
    self.assertEqual(response.runs[0].status, "RUNNING")

  @patch.object(urllib3.PoolManager, 'request')
  def test_delete_run(self, mock_request) -> None:
    """Test case for delete_run

        Delete run
        """
    run_id = "run123"
    expected_response = {
        "delete_input_dir_job_id": "job123",
        "delete_output_dir_job_id": "job124",
        "delete_log_dir_job_id": "job125"
    }

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=202)
    mock_request.return_value = mock_response

    response = self.api.delete_run(run_id)
    self.assertEqual(response.delete_input_dir_job_id, "job123")
    self.assertEqual(response.delete_output_dir_job_id, "job124")
    self.assertEqual(response.delete_log_dir_job_id, "job125")


if __name__ == '__main__':
  unittest.main()



# coding: utf-8

"""
    AI Hub API

    The AI Hub REST API. Please see https://docs.instabase.com for more details.

    The version of the OpenAPI document: 0.1
    Contact: support@instabase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, field_validator
from pydantic import Field
from aihub.models.raise_query_request_source_app_inner import RaiseQueryRequestSourceAppInner
try:
  from typing import Self
except ImportError:
  from typing_extensions import Self


class RaiseQueryRequest(BaseModel):
  """
    RaiseQueryRequest
    """

  # noqa: E501
  query: StrictStr = Field(description="The query to ask the chatbot.")
  model_name: Optional[StrictStr] = Field(
      default=None,
      description="The model could be either 'multistep' or 'multistep-lite'.")
  include_source_info: Optional[StrictBool] = Field(
      default=None,
      description=
      "Set this variable 'true' to get source documents from which the response is fetched."
  )
  source_app: List[RaiseQueryRequestSourceAppInner] = Field(
      description="Source information of the source app.")
  __properties: ClassVar[List[str]] = [
      "query", "model_name", "include_source_info", "source_app"
  ]

  @field_validator('model_name')
  def model_name_validate_enum(cls, value):
    """Validates the enum"""
    if value is None:
      return value

    if value not in ('multistep', 'multistep-lite'):
      raise ValueError(
          "must be one of enum values ('multistep', 'multistep-lite')")
    return value

  model_config = {"populate_by_name": True, "validate_assignment": True}

  def to_str(self) -> str:
    """Returns the string representation of the model using alias"""
    return pprint.pformat(self.model_dump(by_alias=True))

  def to_json(self) -> str:
    """Returns the JSON representation of the model using alias"""
    # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
    return json.dumps(self.to_dict())

  @classmethod
  def from_json(cls, json_str: str) -> Self:
    """Create an instance of RaiseQueryRequest from a JSON string"""
    return cls.from_dict(json.loads(json_str))

  def to_dict(self) -> Dict[str, Any]:
    """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
    _dict = self.model_dump(
        by_alias=True,
        exclude={},
        exclude_none=True,
    )
    # override the default output from pydantic by calling `to_dict()` of each item in source_app (list)
    _items = []
    if self.source_app:
      for _item in self.source_app:
        if _item:
          _items.append(_item.to_dict())
      _dict['source_app'] = _items
    return _dict

  @classmethod
  def from_dict(cls, obj: Dict) -> Self:
    """Create an instance of RaiseQueryRequest from a dict"""
    if obj is None:
      return None

    if not isinstance(obj, dict):
      return cls.model_validate(obj)

    _obj = cls.model_validate({
        "query":
        obj.get("query"),
        "model_name":
        obj.get("model_name"),
        "include_source_info":
        obj.get("include_source_info"),
        "source_app": [
            RaiseQueryRequestSourceAppInner.from_dict(_item)
            for _item in obj.get("source_app")
        ] if obj.get("source_app") is not None else None
    })
    return _obj



import json
import unittest
from unittest.mock import patch
import urllib3

from aihub.api.secrets_api import SecretsApi


class TestSecretsApi(unittest.TestCase):
  """SecretsApi unit test stubs"""

  def setUp(self) -> None:
    self.api = SecretsApi()

  def tearDown(self) -> None:
    pass

  @patch.object(urllib3.PoolManager, 'request')
  def test_update_secret(self, mock_request) -> None:
    """Test case for update_secret

        Update an existing secret
        """
    expected_response = {}

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.update_secret(
        **{
            'alias': 'my_secret',
            'value': 'new_password',
            'description': 'Updated secret description',
            'allowed_workspaces_type': 'ALL'
        })
    self.assertIsNone(response, 'Response should be None for update request')

  @patch.object(urllib3.PoolManager, 'request')
  def test_update_secret_with_specific_workspaces(self, mock_request) -> None:
    """Test case for update_secret with specific workspace permissions"""
    expected_response = {}

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.update_secret(
        **{
            'alias': 'my_secret',
            'value': 'new_password',
            'description': 'Limited access secret',
            'allowed_workspaces_type': 'SOME',
            'allowed_workspaces': ['workspace1', 'workspace2']
        })
    self.assertIsNone(response, 'response should be none for update')

  @patch.object(urllib3.PoolManager, 'request')
  def test_delete_secret(self, mock_request) -> None:
    """Test case for delete_secret

        Delete a secret
        """
    expected_response = {}

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.delete_secret('my_secret')
    self.assertIsNone(response, 'response for delete should be none')

  @patch.object(urllib3.PoolManager, 'request')
  def test_list_secrets(self, mock_request) -> None:
    """Test case for list_secrets

        List all secrets
        """
    expected_response = {
        "secrets": [{
            "alias": "my_secret",
            "description": "Test secret",
            "allowed_workspaces_type": "ALL",
            "allowed_workspaces": [],
            "created_at": "2024-02-12T10:00:00Z",
            "updated_at": "2024-02-12T10:00:00Z"
        }, {
            "alias": "limited_secret",
            "description": "Limited access secret",
            "allowed_workspaces_type": "SOME",
            "allowed_workspaces": ["workspace1"],
            "created_at": "2024-02-12T11:00:00Z",
            "updated_at": "2024-02-12T11:00:00Z"
        }]
    }

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.list_secrets()
    self.assertEqual(len(response.secrets), 2)
    self.assertEqual(response.secrets[0].alias, "my_secret")
    self.assertEqual(response.secrets[0].allowed_workspaces_type, "ALL")
    self.assertEqual(response.secrets[1].alias, "limited_secret")
    self.assertEqual(response.secrets[1].allowed_workspaces_type, "SOME")
    self.assertEqual(len(response.secrets[1].allowed_workspaces), 1)

  @patch.object(urllib3.PoolManager, 'request')
  def test_get_secret(self, mock_request) -> None:
    """Test case for get_secret

        Get a specific secret's metadata
        """
    expected_response = {
        "secrets": [{
            "alias": "my_secret",
            "description": "Test secret",
            "allowed_workspaces_type": "ALL",
            "allowed_workspaces": [],
            "created_at": "2024-02-12T10:00:00Z",
            "updated_at": "2024-02-12T10:00:00Z"
        }]
    }

    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.list_secrets(**{'alias': 'my_secret'})
    secret = response.secrets[0]
    self.assertEqual(secret.alias, "my_secret")
    self.assertEqual(secret.description, "Test secret")
    self.assertEqual(secret.allowed_workspaces_type, "ALL")
    self.assertEqual(len(secret.allowed_workspaces), 0)


if __name__ == '__main__':
  unittest.main()



# coding: utf-8

"""
    AI Hub API

    The AI Hub REST API. See https://docs.instabase.com/api-sdk/ for more details.

    The version of the OpenAPI document: 0.1
    Contact: support@instabase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictInt, StrictStr, field_validator
from pydantic import Field
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class Run(BaseModel):
    """
    Run
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="Run ID of the run.")
    status: Optional[StrictStr] = Field(default=None, description="Status of the run.")
    start_timestamp: Optional[StrictInt] = Field(default=None, description="When the run started, in Unix time.")
    finish_timestamp: Optional[StrictInt] = Field(default=None, description="When the run finished, in Unix time. `null` if run is still in progress.")
    msg: Optional[StrictStr] = Field(default=None, description="Message about the run.")
    __properties: ClassVar[List[str]] = ["id", "status", "start_timestamp", "finish_timestamp", "msg"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('RUNNING', 'COMPLETE', 'PAUSED', 'FAILED', 'CANCELLED', 'STOPPED_AT_CHECKPOINT'):
            raise ValueError("must be one of enum values ('RUNNING', 'COMPLETE', 'PAUSED', 'FAILED', 'CANCELLED', 'STOPPED_AT_CHECKPOINT')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Run from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # set to None if finish_timestamp (nullable) is None
        # and model_fields_set contains the field
        if self.finish_timestamp is None and "finish_timestamp" in self.model_fields_set:
            _dict['finish_timestamp'] = None

        # set to None if msg (nullable) is None
        # and model_fields_set contains the field
        if self.msg is None and "msg" in self.model_fields_set:
            _dict['msg'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of Run from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "status": obj.get("status"),
            "start_timestamp": obj.get("start_timestamp"),
            "finish_timestamp": obj.get("finish_timestamp"),
            "msg": obj.get("msg")
        })
        return _obj





# coding: utf-8

"""
    AI Hub API

    The AI Hub REST API. See https://docs.instabase.com/api-sdk/ for more details.

    The version of the OpenAPI document: 0.1
    Contact: support@instabase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import io
import warnings

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Dict, List, Optional, Tuple, Union, Any

try:
    from typing import Annotated
except ImportError:
    from typing_extensions import Annotated

from pydantic import Field
from typing_extensions import Annotated
from pydantic import StrictStr

from typing import Optional

from aihub.models.create_secret_request import CreateSecretRequest
from aihub.models.delete_secret_request import DeleteSecretRequest
from aihub.models.list_secrets200_response import ListSecrets200Response
from aihub.models.update_secret_request import UpdateSecretRequest

from aihub.api_client import ApiClient
from aihub.api_response import ApiResponse
from aihub.rest import RESTResponseType


class SecretsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_secret(
        self,
        create_secret_request: CreateSecretRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Create secret

        <span class=\"badge\">Commercial & Enterprise</span>  Create a new secret in this organization.  <Note>Only organization admins can create secrets.</Note> 

        :param create_secret_request: (required)
        :type create_secret_request: CreateSecretRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_secret_serialize(
            create_secret_request=create_secret_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_secret_with_http_info(
        self,
        create_secret_request: CreateSecretRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Create secret

        <span class=\"badge\">Commercial & Enterprise</span>  Create a new secret in this organization.  <Note>Only organization admins can create secrets.</Note> 

        :param create_secret_request: (required)
        :type create_secret_request: CreateSecretRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_secret_serialize(
            create_secret_request=create_secret_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_secret_without_preload_content(
        self,
        create_secret_request: CreateSecretRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create secret

        <span class=\"badge\">Commercial & Enterprise</span>  Create a new secret in this organization.  <Note>Only organization admins can create secrets.</Note> 

        :param create_secret_request: (required)
        :type create_secret_request: CreateSecretRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_secret_serialize(
            create_secret_request=create_secret_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_secret_serialize(
        self,
        create_secret_request,
        ib_context,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if ib_context is not None:
            _header_params['IB-Context'] = ib_context
        # process the form parameters
        # process the body parameter
        if create_secret_request is not None:
            _body_params = create_secret_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/aihub/secrets',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_secret(
        self,
        delete_secret_request: DeleteSecretRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete secret

        <span class=\"badge\">Commercial & Enterprise</span>  Delete a secret from the organization.  <Note>Only organization admins can delete secrets.</Note> 

        :param delete_secret_request: (required)
        :type delete_secret_request: DeleteSecretRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_secret_serialize(
            delete_secret_request=delete_secret_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_secret_with_http_info(
        self,
        delete_secret_request: DeleteSecretRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete secret

        <span class=\"badge\">Commercial & Enterprise</span>  Delete a secret from the organization.  <Note>Only organization admins can delete secrets.</Note> 

        :param delete_secret_request: (required)
        :type delete_secret_request: DeleteSecretRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_secret_serialize(
            delete_secret_request=delete_secret_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_secret_without_preload_content(
        self,
        delete_secret_request: DeleteSecretRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete secret

        <span class=\"badge\">Commercial & Enterprise</span>  Delete a secret from the organization.  <Note>Only organization admins can delete secrets.</Note> 

        :param delete_secret_request: (required)
        :type delete_secret_request: DeleteSecretRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_secret_serialize(
            delete_secret_request=delete_secret_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_secret_serialize(
        self,
        delete_secret_request,
        ib_context,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if ib_context is not None:
            _header_params['IB-Context'] = ib_context
        # process the form parameters
        # process the body parameter
        if delete_secret_request is not None:
            _body_params = delete_secret_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/v2/aihub/secrets',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_secrets(
        self,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.")] = None,
        workspace: Annotated[Optional[StrictStr], Field(description="Show secrets available in the specified workspace.  <Info>Only members of a workspace can access secrets that are available within that workspace.</Info> ")] = None,
        alias: Annotated[Optional[StrictStr], Field(description="Get the secret with the specified alias.  ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ListSecrets200Response:
        """List secrets

        <span class=\"badge\">Commercial & Enterprise</span>  List secrets available to the organization, available to a given workspace, or with a given alias.  <Note>Only organization admins can list all secrets in the organization. Non-admins must specify a workspace.</Note> 

        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.
        :type ib_context: str
        :param workspace: Show secrets available in the specified workspace.  <Info>Only members of a workspace can access secrets that are available within that workspace.</Info> 
        :type workspace: str
        :param alias: Get the secret with the specified alias.  
        :type alias: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_secrets_serialize(
            ib_context=ib_context,
            workspace=workspace,
            alias=alias,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListSecrets200Response",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_secrets_with_http_info(
        self,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.")] = None,
        workspace: Annotated[Optional[StrictStr], Field(description="Show secrets available in the specified workspace.  <Info>Only members of a workspace can access secrets that are available within that workspace.</Info> ")] = None,
        alias: Annotated[Optional[StrictStr], Field(description="Get the secret with the specified alias.  ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ListSecrets200Response]:
        """List secrets

        <span class=\"badge\">Commercial & Enterprise</span>  List secrets available to the organization, available to a given workspace, or with a given alias.  <Note>Only organization admins can list all secrets in the organization. Non-admins must specify a workspace.</Note> 

        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.
        :type ib_context: str
        :param workspace: Show secrets available in the specified workspace.  <Info>Only members of a workspace can access secrets that are available within that workspace.</Info> 
        :type workspace: str
        :param alias: Get the secret with the specified alias.  
        :type alias: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_secrets_serialize(
            ib_context=ib_context,
            workspace=workspace,
            alias=alias,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListSecrets200Response",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_secrets_without_preload_content(
        self,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.")] = None,
        workspace: Annotated[Optional[StrictStr], Field(description="Show secrets available in the specified workspace.  <Info>Only members of a workspace can access secrets that are available within that workspace.</Info> ")] = None,
        alias: Annotated[Optional[StrictStr], Field(description="Get the secret with the specified alias.  ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List secrets

        <span class=\"badge\">Commercial & Enterprise</span>  List secrets available to the organization, available to a given workspace, or with a given alias.  <Note>Only organization admins can list all secrets in the organization. Non-admins must specify a workspace.</Note> 

        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.
        :type ib_context: str
        :param workspace: Show secrets available in the specified workspace.  <Info>Only members of a workspace can access secrets that are available within that workspace.</Info> 
        :type workspace: str
        :param alias: Get the secret with the specified alias.  
        :type alias: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_secrets_serialize(
            ib_context=ib_context,
            workspace=workspace,
            alias=alias,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListSecrets200Response",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_secrets_serialize(
        self,
        ib_context,
        workspace,
        alias,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if workspace is not None:
            
            _query_params.append(('workspace', workspace))
            
        if alias is not None:
            
            _query_params.append(('alias', alias))
            
        # process the header parameters
        if ib_context is not None:
            _header_params['IB-Context'] = ib_context
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2/aihub/secrets',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_secret(
        self,
        update_secret_request: UpdateSecretRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Update secret

        <span class=\"badge\">Commercial & Enterprise</span>  Update the description, value, or allowed workspaces for a secret. If a value for a parameter is not specified, it will remain the same.  <Note>Only organization admins can update secrets.</Note> 

        :param update_secret_request: (required)
        :type update_secret_request: UpdateSecretRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_secret_serialize(
            update_secret_request=update_secret_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_secret_with_http_info(
        self,
        update_secret_request: UpdateSecretRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Update secret

        <span class=\"badge\">Commercial & Enterprise</span>  Update the description, value, or allowed workspaces for a secret. If a value for a parameter is not specified, it will remain the same.  <Note>Only organization admins can update secrets.</Note> 

        :param update_secret_request: (required)
        :type update_secret_request: UpdateSecretRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_secret_serialize(
            update_secret_request=update_secret_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_secret_without_preload_content(
        self,
        update_secret_request: UpdateSecretRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update secret

        <span class=\"badge\">Commercial & Enterprise</span>  Update the description, value, or allowed workspaces for a secret. If a value for a parameter is not specified, it will remain the same.  <Note>Only organization admins can update secrets.</Note> 

        :param update_secret_request: (required)
        :type update_secret_request: UpdateSecretRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_secret_serialize(
            update_secret_request=update_secret_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_secret_serialize(
        self,
        update_secret_request,
        ib_context,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if ib_context is not None:
            _header_params['IB-Context'] = ib_context
        # process the form parameters
        # process the body parameter
        if update_secret_request is not None:
            _body_params = update_secret_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/v2/aihub/secrets',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


